@@ -220,8 +220,8 @@ namespace pinocchio
         .add_property("nvs",&Model::nvs)          
         .add_property("parents",&Model::parents)
         .add_property("names",&Model::names)
-        .add_property("name",&Model::name)
-        .add_property("referenceConfigurations", &Model::referenceConfigurations)
+        .def_readwrite("name",&Model::name)
+        .def_readwrite("referenceConfigurations", &Model::referenceConfigurations)
         
         .def_readwrite("rotorInertia",&Model::rotorInertia,
                        "Vector of rotor inertia parameters.")
